starcluster.progressbar.Fraction

Package starcluster :: Module progressbar :: Class Fraction |
[hide private]
[frames] | no frames]

# Class Fraction

source code

Just the fraction done.

Instance Methods | [hide private]
update(self, pbar) Returns the string representing the widget. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### update(self, pbar) | source code
Returns the string representing the widget. The parameter pbar is a reference to the calling ProgressBar, where one can access attributes of the class for knowing how the update must be made. At least this function must be overriden. Overrides: ProgressBarWidget.update (inherited documentation)